%%   -----------------------------
%%   The ACOUSTICS-CONF-2009 class
%%   -----------------------------
%%   Copyright 2009 Will Robertson
%%
%%   Licence information appended

% Quickly compiled class for the 2009 conference Acoustics, 
% held in Adelaide, Australia. Ad hoc design, ad hoc class.
% Please contact me if you would like a more formal class
% designed for future conferences.

\ProvidesClass{acoustics-conf-2009}
  [2009/05/22 v0.1 Class file for the Acoustics conference]

\LoadClass[twoside]{article}
\RequirePackage[9pt]{extsizes}

%% fonts
\usepackage{mathptmx}
\renewcommand\ttdefault{txtt}
\RequirePackage[scaled=1]{helvet}
\normalfont
\RequirePackage[T1]{fontenc}
\RequirePackage{textcomp}

%% other packages
\RequirePackage{
  amsmath,amssymb,bm,array,booktabs,calc,fixltx2e
}

%% design

\frenchspacing
\linespread{0.95}

% paper size, page size
\RequirePackage[
    a4paper,
    vmargin={17.5mm, 25mm},
    hmargin={17.5mm, 22.5mm},
    headsep=6pt,
  ]{geometry}
\setlength\columnsep{12.5mm}

% paragraph spacing
\newlength\thisparskip
\setlength\thisparskip{9pt}
\setlength\parskip{\thisparskip}
\setlength\parindent{0pt}

% Floats, tables, figures
\RequirePackage[skip=4.5pt,tableposition=top]{caption}
\g@addto@macro\maketitle{%
  \setlength\extrarowheight{2pt}%
}
\newcommand\source[1]{%
  \ifvmode\else\par\fi 
  \smallskip\small 
  Source:~#1%
}

% centre figures, tables:
\renewcommand\figure[1][htbp]{\@float{figure}[#1]\centering}
\renewcommand\table[1][htbp]{\@float{table}[#1]\centering}

% sections
\setcounter{secnumdepth}{-1}
\usepackage[bf,sf]{titlesec}
\titlespacing*{\section}{0pt}{0pt}{-2pt}
\titlespacing*{\subsection}{0pt}{0pt}{-2pt}
\titlespacing*{\subsubsection}{0pt}{0pt}{-2pt}
\titleformat{\section}{\sffamily\bfseries\large}{\thesection}{0pt}{\MakeUppercase}
\titleformat{\subsection}{\sffamily\bfseries}{\thesubsection}{0pt}{}
\titleformat{\subsubsection}{\sffamily\bfseries\small}{\thesubsubsection}{0pt}{}

% lists
\RequirePackage{enumitem}
\setlist{nolistsep,topsep=-0.5\parskip}

% quotations
\renewenvironment{quote}{%
  \par
  \fontsize{8pt}{9pt}\selectfont
  \setlength\parskip{0pt}
  \list {}{\topsep=0pt \rightmargin=1cm \leftmargin=1cm}\item \relax
}{%
  \endlist
}
\renewenvironment{quotation}{\quote}{\endquote}

% header/footer:
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\g@addto@macro\maketitle{\thispagestyle{fancy}}% use this pagestyle even on the first page

\fancyhead{}
\fancyhead[LO,RE]{\small Proceedings of ACOUSTICS 2009}
\fancyhead[RO,LE]{\small 23--25 November 2009, Adelaide, Australia}
\def\headrulewidth{0pt}

\fancyfoot{}
\fancyfoot[LO,RE]{\small Australian Acoustical Society}
\fancyfoot[RO,LE]{\small \thepage}

%% bibliography setup
\AtBeginDocument{%
  \@ifpackageloaded{biblatex}{%
    \setlength\bibhang{5mm}
  }{}
  \@ifpackageloaded{natbib}{%
    \RequirePackage{hypernat}
    % (in case natbib is loaded and the author 
    %  doesn't realise the clash with hyperref)
    \setlength\bibhang{5mm}
    \setlength\bibsep{0pt}
  }{}
}


%% FRONTMATTER

\date{}% (no date)

% onecol abstract
\usepackage[number]{abstract}
\def\abstracttextfont{\normalfont}
\setlength\absleftindent{1cm}
\setlength\absrightindent{1cm}
\setlength\abstitleskip{2\baselineskip}
\def\num@bs{\section*{\abstractname}}

\renewenvironment{abstract}{%
  \vspace{-2\baselineskip}%
  \num@bs
  \vspace{\thisparskip}
  \begin{@bstr@ctlist}
    \if@bsrunin\@bsrunintitle\fi
    \abstracttextfont
}{%
    \par
  \end{@bstr@ctlist}
  \vspace{\baselineskip}%
}

%% title
% you are not necessarily supposed to understand this: (bit of a hack to avoid having to edit \@maketitle)
\AtBeginDocument{%
  \edef\@title{%
    \unexpanded{\sffamily\bfseries\fontsize{18}{18}\selectfont}%
    \unexpanded\expandafter{\@title}}%
  \edef\@author{%
    \unexpanded{\sffamily\bfseries\LARGE}%
    \unexpanded\expandafter{\@author}}%
}
\newcommand\affiliations[1]{%
  \g@addto@macro\@author{%
  \end{tabular}
  \par
  \setlength\extrarowheight{0pt}
  \begin{tabular}{@{}c@{}}
    #1
  }%
}

%%%%%%%%%%%%

%% hyperref: (not really necessary but nice to set up automatically)
\RequirePackage{hyperref}
\hypersetup{
  colorlinks,
  linkcolor=black,
  anchorcolor=black,
  citecolor=black,
  filecolor=black,
  menucolor=black,
  pagecolor=black,
  urlcolor=black,
  pdfstartview=FitH,
  pdfpagelayout=SinglePage
}


%% Copyright 2009 by Will Robertson <wspr81@gmail.com>
%% 
%% Distributable under the LaTeX Project Public License,
%% version 1.3c or higher (your choice). The latest version of
%% this license is at: http://www.latex-project.org/lppl.txt
%% 
%% This work is "maintained" (as per LPPL maintenance status)
%% by Will Robertson.
%% 
%% This work consists of the file acoustics-conf-2009.cls.
